import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

dirname = os.path.dirname(__file__)

packages, package_dir = find_packages(dirname)
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-base',
    version='0.1', 
    description='base elisa components',
    long_description='base elisa components',
    license='UNKNOWN', 
    author='Elisa Developers',
    author_email='elisa@lists.fluendo.com',
    keywords='',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    package_data={'': ['*.png', '*.mo', '*.po']},
    entry_points="""
    [elisa.core.components.resource_provider]
    LocalResource = elisa.plugins.base.local_resource:LocalResource
    """,
    cmdclass=cmdclass)
